pub enum StatementEvent {
NewStatements {
statements: Vec<Bytes>,
remaining: Option<u32>,
},
}Expand description
An item returned by the statement subscription stream.
Variants
NewStatements
A batch of statements matching the subscription filter.
Fields

statements: Vec<Bytes>A batch of statements matching the subscription filter, each entry is a SCALE-encoded statement.

remaining: Option<u32>An optional count of how many more matching statements are in the store after this batch. This guarantees to the client that it will receive at least this many more statements in the subscription stream, but it may receive more if new statements are added to the store that match the filter.